@@ -110,7 +110,7 @@ def fault_timestamp():
 class EventParsing:
     """Test cases for event parsing.
 
-    Emits these fields: "line, account_id, type, code, error, extended_data_flag"
+    Emits these fields: "line, account_id, code_type, code, error, extended_data_flag, encrypted_flag"
 
     """
 
@@ -123,6 +123,7 @@ class EventParsing:
             "CL",
             None,
             False,
+            False,
         )
 
     def case_bug2(self):
@@ -134,6 +135,7 @@ class EventParsing:
             "KR",
             None,
             False,
+            False,
         )
 
     def case_dc04(self):
@@ -145,6 +147,7 @@ class EventParsing:
             None,
             EventFormatError,
             False,
+            False,
         )
 
     def case_adm_cid(self):
@@ -156,6 +159,7 @@ class EventParsing:
             "FA",
             None,
             False,
+            False,
         )
 
     def case_adm_cid2(self):
@@ -167,6 +171,7 @@ class EventParsing:
             "CL",
             None,
             False,
+            False,
         )
 
     def case_code_jc(self):
@@ -178,6 +183,7 @@ class EventParsing:
             "JC",
             None,
             False,
+            False,
         )
 
     def case_xdata_M(self):
@@ -189,6 +195,7 @@ class EventParsing:
             "CL",
             None,
             True,
+            False,
         )
 
     def case_xdata_K(self):
@@ -200,6 +207,7 @@ class EventParsing:
             "RP",
             None,
             True,
+            False,
         )
 
     def case_xdata_X_and_Y(self):
@@ -211,6 +219,7 @@ class EventParsing:
             "PA",
             None,
             True,
+            False,
         )
 
     # TODO: add tests for different SIA versions (DC-04, DC09, DC09X)
@@ -223,6 +232,19 @@ class EventParsing:
             None,
             None,
             False,
+            True,
+        )
+
+    def case_encrypted_adm(self):
+        """Input a encrypted ADM line."""
+        return (
+            r'D0850078"*ADM-CID"6879R0L0#123F[64F7ADD9BA9377DBF2C014BC709329BEEE345B5F20C60B7EB9D2C6B8C222666B13D0B4A114B448B0AC555FCC658DB6EE',
+            "123F",
+            None,
+            None,
+            None,
+            False,
+            True,
         )
 
     def case_oh(self):
@@ -234,6 +256,7 @@ class EventParsing:
             "RP",
             None,
             False,
+            False,
         )
 
     def case_cl(self):
@@ -245,6 +268,7 @@ class EventParsing:
             "CL",
             None,
             False,
+            False,
         )
 
     def case_op(self):
@@ -256,6 +280,7 @@ class EventParsing:
             "OP",
             None,
             False,
+            False,
         )
 
     def case_null(self):
@@ -267,6 +292,7 @@ class EventParsing:
             None,
             None,
             False,
+            True,
         )
 
     def case_wa(self):
@@ -278,6 +304,7 @@ class EventParsing:
             "WA",
             None,
             False,
+            False,
         )
 
     def case_eventformaterror(self):
@@ -289,6 +316,7 @@ class EventParsing:
             None,
             EventFormatError,
             False,
+            False,
         )
 
 
